====================
sphinx-users.jp 会則
====================

総 則
======

第１条 （名 称）
----------------
本会はsphinx-users.jp(通称 #sphinxjp)と称する。

第２条 （事務局所在地）
-----------------------
本会は事務局を以下の住所に置き、本会の所在地とする。

目的及び事業
============

第３条 （目 的）
----------------
Python製ドキュメンテーションビルダー Sphinx の日本への普及を推進するこ
と。

第４条 （事 業）
----------------
本会は目的達成の為、Sphinxの日本語対応のための開発、日本国内のSphinx
利用者および開発者の支援、セミナーや展示会への出展などを行う。


会 員
=====

第５条 （会員種別）
-------------------
会員種別として個人会員を設ける。

第６条 （入 会）
----------------
本会の個人会員になろうとする者は、別途定める本会主催のメーリングリスト
に参加することによって会員と認定されるものとする。

第７条 （退 会）
-----------------
会員は下記の場合に退会とみなされる。

1. 個人会員が本会主催の全メーリングリストから脱退したとき。
2. 個人会員が死亡したとき。
3. 本会が解散したとき。

第８条 （除 名）
----------------
次の各項に相当する場合、会長は会員を除名できる。

1. 本会主催のMLのメールが送信できない状態の者
2. 本会会則に従わない者
3. 本会の名誉を著しく傷つける行為を行った者
4. 本会の活動を妨害する者
5. 1に該当する者はML管理者の権限で除名できるものとする。
   2～4に該当する除名は運営スタッフの協議のうえ、全スタッフの
   過半数の賛成を持って実行される。

